function pfWrite(polygonFilename, pf, sz)
% 
% Creates a text file compatible with polytracker
%
% pfWrite(polygonFilename, pf)
%
% Fields allowed in pf:
%    pf.class
%    pf.vertices
%    pf.view (optional)
%    pf.labels (optional) with labels being a struct
%    

if nargin < 3, sz = []; end

Nobjects = size(pf,2);

fid = fopen(polygonFilename,'w');
fprintf(fid,'\n');
fprintf(fid,'# --pfWrite------------\n');
fprintf(fid,'# - List of Polygons   \n');
fprintf(fid,'# ---------------------\n');
if ~isempty(sz)
    if length(sz==2); sz(3) = 1; end
    fprintf(fid,'size {%d %d %d}\n', sz(1), sz(2), sz(3));
end
fprintf(fid,'\n');

for j = 1:Nobjects
    vertices = pf(j).vertices;
    vertices = num2str(fix(vertices(:)'));
    
    if ~isfield(pf(j), 'polygon')
        pf(j).polygon = deblank(num2str(j));
    end
    
    fprintf(fid,'makePolygon {%s} %s {%s}\n',pf(j).polygon, pf(j).class, vertices);
    
    if isfield(pf(j), 'view')
        pView = pf(j).view;
        if length(pView)>0
            pView = num2str(fix(pView(:)'));
            fprintf(fid,'view {%s}\n', pView);
        end
    end
    if isfield(pf(j), 'labels')
        labels = pf(j).labels;
        if length(labels)>0
            fieldName = fieldnames(labels);
            
            Nfields = length(fieldName);
            
            fprintf(fid,'labels {');
            for nf = 1:Nfields
                fieldContent = getfield(labels, fieldName{nf});
                fprintf(fid,'{%s:%s}',fieldName{nf}, fieldContent);
            end
            fprintf(fid,'}\n');
        end
    end
end

fclose(fid);


