function showImages(DB, frames, Nfigures, bbox)
% function showImages(DB, frames, Nfigures)
% Show the images and annotations 
%
% Examples:
% keys = queryDB(DB, 'findCategory', 'office')
% showImages(DB, [keys(1:10).frame])
%
% frames =  strmatch('office',{DB.frame(1:10).placeCatName})
% showImages(DB, frames)
%
% showImages(DB, 1:15, 2)
%    shows all the 15 images distributed in two figures
%
% showImages(DB, frame, 1, bbox)
% display bounding boxes bbox(r,:) as dotted rectangles

if nargin == 1
    frames = 1:length(DB.frame);
end
if nargin < 3, Nfigures = 1;  end
use_subplot = 1;
if nargin < 4, bbox = []; end

make_legend = 1;
objectNames = DB.objectNames;
Nimgs = length(frames);


Nplots = ceil((Nimgs / Nfigures) + 1); % add 1 for legend
ncols_plot = ceil(sqrt(Nplots));
nrows_plot = ceil(Nplots/ncols_plot);
Nplots = nrows_plot*ncols_plot;


color =['r' 'b' 'g' 'c' 'm' 'y' 'k'];
ncolors = length(color);

fi = 1;
done = 0;
for fig=1:Nfigures
    figure;
    used_otype_nums = [];
    for p=1:Nplots
        subplot(nrows_plot, ncols_plot, p);
        if p==nrows_plot*ncols_plot | fi>length(frames) % last subplot
            used_otype_nums = unique(used_otype_nums);
            for oi=1:length(used_otype_nums)
                o = used_otype_nums(oi);
                dummy_handle(oi) = line([0 0.1], [0 0.1]);
                set(dummy_handle(oi), 'color', color(mod(o, ncolors)+1));
                set(dummy_handle(oi), 'visible', 'off');
                set(dummy_handle(oi), 'linewidth', 3);
                legend(dummy_handle, objectNames(used_otype_nums), 2);
            end
            if fi>length(frames), break; end
        else
            f = frames(fi);
            entry = DB.frame(f);
            %fname = fullfile(DB.imagesFolder, entry.fileNameImage);
            fname = fullfile(DB.imagesFolder, entry.folder, entry.fileNameImage);
            img = imread(fname);
            %ttl = sprintf('%s frame %d', strrep(entry.folder, '_', '-'), entry.frameNum);
            ttl = strrep(sprintf('%s/%s', entry.folder, entry.fileNameImage), '_', '-');
            image(img); 
            %axis('square');
            axis('equal'); 
            axis('off');axis('tight')
            grid('off')
            hold on
            title(ttl)
            %hy = ylabel(strrep(entry.placeCatName, '_', '-')); set(hy,'visible','on');
            hy = ylabel(strrep(entry.placeName, '_', '-')); set(hy,'visible','on');
            
            Nobj = length(entry.objects);
            %used_otype_nums = [];
            for o=1:Nobj
                obj = entry.objects(o);
                otype_num = strmatch(obj.className, objectNames, 'exact');
                if length(otype_num) ~= 1
                    error(sprintf('problem with object name %s', obj.className))
                end
                used_otype_nums = [used_otype_nums otype_num(:)'];
                col = color(mod(otype_num, ncolors)+1);

                X = obj.vertices(1,:); X = [X X(1)];
                Y = obj.vertices(2,:); Y = [Y Y(1)];
                handle = plot(X, Y);

                set(handle, 'color', col);
                set(handle, 'linewidth', 3);
            end
            
            if ~isempty(bbox)
                assert(length(frames)==1)
                for o=1:size(bbox,1)
                    bb = bbox(o,:);
                    xmin = bb(1);  xmax = bb(2); ymin = bb(3); ymax = bb(4);
                    w = xmax-xmin;
                    h = ymax-ymin;
                    handle = rectangle('position', round([xmin, ymin, w h]));

                    set(handle, 'linewidth', 3);
                    set(handle, 'edgecolor', 'k');
                    set(handle, 'linestyle', '--'); 
                end
            end
            
            fi = fi + 1;
        end % if
    end % for p
    axis('tight')
    %if fi>length(frames)+1, break; end
    drawnow
end % for fig


