function statsDB(DB, goodObjects)

if nargin == 1
    goodObjects = 0;
end

Nframes = length(DB.frame);
keys = queryDB(DB, 'findAnnotated');
Nannotated = length(keys);
j = [keys(:).frame];
data = DB.frame(j)

objectsList = [];

for i = 1:Nannotated
    objects = data(i).objects;
    objectsList =[objectsList {objects(:).className}];
    
end

if goodObjects == 0
    objects = unique(objectsList);
else
    objects = {'head', 'personWalking', 'screenFrontal', 'keyboard', 'mouse', 'chairWhole', ...
            'coffeemachineWhole', 'deskFrontal', 'bookshelfFrontal', 'poster', 'tableLamp', ...
            'telephone', 'wallClock', 'mug', 'trashWhole', 'buildingWhole', 'carFrontal', ...
            'carSide'};
end

N = length(objects);

for i = 1:N
    j = strmatch(objects{i}, objectsList,'exact');
    countsObjects(i) = length(j);
end

[countsObjects, k] = sort(countsObjects);
objects = objects(k);

figure
h = barh(countsObjects);
set(gca, 'YTick', 1:N)
set(gca, 'YTickLabel', objects)
set(gca, 'FontSize', 7)
grid on
title(sprintf('Anotated files: %d', Nannotated))


for n = 1:N
    pos_keys = queryDB(DB, 'findObject', objects{n});
    ratio(n) = getShapeStatistics(DB, pos_keys);
end

[foo, k] = sort(ratio);
figure
h = barh(ratio(k));
set(gca, 'YTick', 1:N)
set(gca, 'YTickLabel', objects(k))
set(gca, 'FontSize', 7)
grid on
title(sprintf('Shape ratios for Anotated files: %d', Nannotated))

figure
j = find(countsObjects(k)>49);
h = barh(ratio(k(j)));
set(gca, 'YTick', 1:length(j))
set(gca, 'YTickLabel', objects(k(j)))
set(gca, 'FontSize', 7)
grid on
title(sprintf('Shape ratios for Anotated files (at least 50 items labeled for each object).'))


Boundary = 3; boundaryExtension = 0; 
zoomUp = 'off'; avoidCrop = 'on'; deform = 'off';

Nx = fix(sqrt(N)); Ny = fix(N / Nx)+1;
figure
    average = 0;
for n = 1:N
    pos_keys = queryDB(DB, 'findObject', objects{n});
    NPositiveFrames = length([pos_keys]);
    NPositiveObjects = length([pos_keys.objects]);
    
    ratio = getShapeStatistics(DB, pos_keys);
    maxPatchSize = 32;
    maxPatchSize = 64;
    ratio = 1;
    patchSize = [1 1]; 
    patchSize = round(patchSize / max(patchSize)*maxPatchSize);
%    average = 0;
    count = 0;
    for j = 1:NPositiveFrames
        if count == 0
            NPositiveFrames - j
            drawnow
            
            f = pos_keys(j).frame;
            fileNameImage = fullfile(DB.imagesFolder, DB.frame(f).folder, DB.frame(f).fileNameImage);
            %img = mean(imread(fileNameImage),3);
            img = imread(fileNameImage);
            [nrows ncols ncolors] = size(img);
            
            Nobjects = length(pos_keys(j).objects);
            for i = 1:Nobjects
                rectangle = DB.frame(f).objects(pos_keys(j).objects(i)).bbox;
                
                [patch, cx, cy, s, res] = getObjectPatch(img, rectangle', ...
                    'boundaryExtension', boundaryExtension, 'boundary', Boundary, 'patchSize', patchSize, 'zoomUp', zoomUp, 'avoidCrop', avoidCrop, 'deform', deform);
                
                patch = patch - mean(patch(:)); patch = patch / std(patch(:));
                if ~isempty(patch); 
                    if count ==0
                        average = average + patch;
                        count = count+1;
                        subplot(Nx, Ny, n)
                        %imagesc(patch); axis('off'); colormap(gray(256)); axis('equal'); axis('tight'); title(objects{n}); drawnow
                        a = average; a = a-min(a(:)); a = a/max(a(:));
                        imagesc(a); axis('off'); colormap(gray(256)); 
                        axis('equal'); axis('tight'); h=title(sprintf('%s(%d)',objects{n},count)); 
                        set(h,'fontSize', 6)
                        drawnow
                    end
                    
                end
            end
        end
    end
end
